import { Button, SxProps, Theme } from "@mui/material";

interface Props {
  children: string;
  sx?: SxProps<Theme>;
}

export default function RoundedButton({ children, sx }: Props) {
  return (
    <Button
      disableRipple
      variant="outlined"
      startIcon={<ArrowRightIcon />}
      sx={{
        backgroundColor: "white",
        borderColor: "white",
        borderRadius: "22px",
        color: "#7E2AEA",
        py: "12px",
        px: "64px",
        boxShadow: "none",
        position: "relative",
        textTransform: "none",
        fontWeight: 500,
        fontSize: "16px",
        lineHeight: "20px",
        ".MuiButton-startIcon": {
          position: "absolute",
          top: 0,
          left: 0,
          mr: 0,
          ml: 0,
        },
        "&:hover": {
          transition: "0.5s",
          backgroundColor: "#7E2AEA",
          color: "white",
          border: "1px solid #7E2AEA",

          ".MuiButton-startIcon": {
            transition: "0.5s",
            position: "absolute",
            top: 0,
            left: 252,
            mr: 0,
            ml: 0,
          },
        },
        "&:hover rect": {
          fill: "white",
        },
        "&:hover path": {
          fill: "#7E2AEA",
        },
        ...sx,
      }}
    >
      {children}
    </Button>
  );
}

function ArrowRightIcon() {
  return (
    <svg width="44" height="44" viewBox="0 0 44 44" fill="none" xmlns="http://www.w3.org/2000/svg">
      <rect width="44" height="44" rx="22" fill="#7E2AEA" />
      <path
        d="M20.4034 26.808H23.2834L27.6674 21.88L23.2834 16.952H20.4034L23.8754 20.936H16.3394V22.824H23.8754L20.4034 26.808Z"
        fill="white"
      />
    </svg>
  );
}
