import { Typography, Box, SxProps, Theme, useTheme } from "@mui/material";

interface Props {
  indexText: string;
  header: string;
  descriptionItems: string[];
  cost: string;
  sx?: SxProps<Theme>;
}

export default function TariffCard({ indexText, header, descriptionItems, cost, sx }: Props) {
  const theme = useTheme();

  return (
    <Box
      sx={{
        width: "100%",
        p: "20px",
        backgroundColor: "#333647",
        borderRadius: "12px",
        display: "flex",
        justifyContent: "space-between",
        flexWrap: "wrap",
        minHeight: "300px",
        boxShadow: `
                0px 12.5216px 38.6916px rgba(37, 39, 52, 0.12),
                0px 6.6501px 20.5488px rgba(37, 39, 52, 0.0969343),
                0px 2.76726px 8.55082px rgba(37, 39, 52, 0.0674749)
            `,
        ...sx,
      }}
    >
      <Box>
        <Typography variant="h4" color="#7E2AEA">
          {indexText}
        </Typography>
        <Typography variant="h4" color="white">
          {header}
        </Typography>
        <Box
          component="ul"
          sx={{
            mt: "30px",
            pl: "25px",
            color: "white",
          }}
        >
          {descriptionItems.map((textItem, index) => (
            <li key={index}>
              <Typography variant="t1">{textItem}</Typography>
            </li>
          ))}
        </Box>
      </Box>
      <Box
        sx={{
          display: "flex",
          justifyContent: "center",
          alignItems: "center",
          maxWidth: "637px",
          width: "100%",
        }}
      >
        <Box
          sx={{
            padding: "35px 100px",

            display: "flex",
            justifyContent: "center",
            alignItems: "center",
            backgroundColor: "#7E2AEA",
            borderRadius: "12px",
            boxShadow: `
                        0px 12.5216px 38.6916px rgba(37, 39, 52, 0.12),
                        0px 6.6501px 20.5488px rgba(37, 39, 52, 0.0969343),
                        0px 2.76726px 8.55082px rgba(37, 39, 52, 0.0674749)
                    `,
            filter: `
                        drop-shadow(0px 100px 80px rgba(126, 42, 234, 0.07))
                        drop-shadow(0px 41.7776px 33.4221px rgba(126, 42, 234, 0.0503198))
                        drop-shadow(0px 22.3363px 17.869px rgba(126, 42, 234, 0.0417275)) drop-shadow(0px 12.5216px 10.0172px rgba(126, 42, 234, 0.035))
                        drop-shadow(0px 6.6501px 5.32008px rgba(126, 42, 234, 0.0282725))
                        drop-shadow(0px 2.76726px 2.21381px rgba(126, 42, 234, 0.0196802))
                    `,
            [theme.breakpoints.down("md")]: {
              padding: "30px 74px",
            },
          }}
        >
          <Typography
            sx={{
              whiteSpace: "nowrap",
              color: "white",
              fontWeight: 500,
              fontSize: "39px",
              lineHeight: "100%",
              [theme.breakpoints.down("md")]: {
                fontSize: "24px",
              },
            }}
          >
            {cost}
          </Typography>
        </Box>
      </Box>
    </Box>
  );
}
